# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWhereToWatch(BaseModel):
    get_where_to_watch: Optional[
        List[Optional["GetWhereToWatchGetWhereToWatch"]]
    ] = Field(alias="getWhereToWatch")


class GetWhereToWatchGetWhereToWatch(BaseModel):
    id: Optional[int]
    intro_text: Optional[str] = Field(alias="introText")
    bottom_text: Optional[str] = Field(alias="bottomText")
    banner_strapline: Optional[str] = Field(alias="bannerStrapline")
    desktop_banner_id: Optional[str] = Field(alias="desktopBannerId")
    desktop_banner_image_edited: Optional[str] = Field(alias="desktopBannerImageEdited")
    mobile_banner_id: Optional[str] = Field(alias="mobileBannerId")
    mobile_banner_image_edited: Optional[str] = Field(alias="mobileBannerImageEdited")
    banner_url: Optional[str] = Field(alias="bannerUrl")
    is_live: Optional[bool] = Field(alias="isLive")
    event_days_count: Optional[int] = Field(alias="eventDaysCount")
    event_days_filled_count: Optional[int] = Field(alias="eventDaysFilledCount")
    end_date: Optional[str] = Field(alias="endDate")
    event_level_general_channels: Optional[
        List[Optional["GetWhereToWatchGetWhereToWatchEventLevelGeneralChannels"]]
    ] = Field(alias="eventLevelGeneralChannels")


class GetWhereToWatchGetWhereToWatchEventLevelGeneralChannels(BaseModel):
    category: Optional[str]
    channel_id: Optional[str] = Field(alias="channelId")
    logo_id: Optional[str] = Field(alias="logoId")
    logo_file_name: Optional[str] = Field(alias="logoFileName")
    title: Optional[str]
    days: Optional[
        List[Optional["GetWhereToWatchGetWhereToWatchEventLevelGeneralChannelsDays"]]
    ]


class GetWhereToWatchGetWhereToWatchEventLevelGeneralChannelsDays(BaseModel):
    day: Optional[int]
    date: Optional[Any]
    session_first_url: Optional[str] = Field(alias="sessionFirstUrl")
    session_second_url: Optional[str] = Field(alias="sessionSecondUrl")
    countries: Optional[List[Optional[str]]]


GetWhereToWatch.model_rebuild()
GetWhereToWatchGetWhereToWatch.model_rebuild()
GetWhereToWatchGetWhereToWatchEventLevelGeneralChannels.model_rebuild()



# Generated by ariadne-codegen on 2024-07-30 11:46
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCISCompetitorResDate(BaseModel):
    get_c_i_s_competitor_res_date: Optional[
        "GetCISCompetitorResDateGetCISCompetitorResDate"
    ] = Field(alias="getCISCompetitorResDate")


class GetCISCompetitorResDateGetCISCompetitorResDate(BaseModel):
    parameters: Optional["GetCISCompetitorResDateGetCISCompetitorResDateParameters"]
    active_years: Optional[List[Optional[str]]] = Field(alias="activeYears")
    with_remark: Optional[bool] = Field(alias="withRemark")
    results_by_date: Optional[
        List[Optional["GetCISCompetitorResDateGetCISCompetitorResDateResultsByDate"]]
    ] = Field(alias="resultsByDate")


class GetCISCompetitorResDateGetCISCompetitorResDateParameters(BaseModel):
    results_by_year: Optional[int] = Field(alias="resultsByYear")
    results_by_year_order_by: Optional[str] = Field(alias="resultsByYearOrderBy")


class GetCISCompetitorResDateGetCISCompetitorResDateResultsByDate(BaseModel):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


GetCISCompetitorResDate.update_forward_refs()
GetCISCompetitorResDateGetCISCompetitorResDate.update_forward_refs()
GetCISCompetitorResDateGetCISCompetitorResDateParameters.update_forward_refs()
GetCISCompetitorResDateGetCISCompetitorResDateResultsByDate.update_forward_refs()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetPredictorGameNotification(BaseModel):
    get_predictor_game_notification: Optional[
        "GetPredictorGameNotificationGetPredictorGameNotification"
    ] = Field(alias="getPredictorGameNotification")


class GetPredictorGameNotificationGetPredictorGameNotification(BaseModel):
    id: Optional[int]
    notification_text: Optional[str] = Field(alias="notificationText")
    notification_button_text: Optional[str] = Field(alias="notificationButtonText")
    notification_url: Optional[str] = Field(alias="notificationUrl")
    created_at: Optional[Any] = Field(alias="createdAt")
    published_at: Optional[Any] = Field(alias="publishedAt")


GetPredictorGameNotification.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetContactPreferences(BaseModel):
    get_contact_preferences: Optional[
        "GetContactPreferencesGetContactPreferences"
    ] = Field(alias="getContactPreferences")


class GetContactPreferencesGetContactPreferences(BaseModel):
    success: bool
    data: Optional["GetContactPreferencesGetContactPreferencesData"]
    error: Optional[str]


class GetContactPreferencesGetContactPreferencesData(BaseModel):
    contact_preferences: Optional[List[Optional[str]]] = Field(
        alias="contactPreferences"
    )
    consents: Optional[List[Optional[str]]]


GetContactPreferences.model_rebuild()
GetContactPreferencesGetContactPreferences.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVideoList(BaseModel):
    get_video_list: Optional[List[Optional["GetVideoListGetVideoList"]]] = Field(
        alias="getVideoList"
    )


class GetVideoListGetVideoList(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[str]
    language: Optional[str]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    tags: Optional[List[Optional[str]]]
    title: Optional[str]
    thumbnail_id: Optional[str] = Field(alias="thumbnailId")
    thumbnail_edited: Optional[str] = Field(alias="thumbnailEdited")
    video_id: Optional[str] = Field(alias="videoId")
    player_id: Optional[str] = Field(alias="playerId")
    tag_id: Optional[str] = Field(alias="tagId")
    stand_first: Optional[str] = Field(alias="standFirst")
    signed_in_cta: Optional[str] = Field(alias="signedInCTA")
    signed_out_cta: Optional[str] = Field(alias="signedOutCTA")
    metatags: Optional[str]
    thumbnail_title: Optional[str] = Field(alias="thumbnailTitle")


GetVideoList.model_rebuild()



# Generated by ariadne-codegen
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SignCookies(BaseModel):
    sign_cookies: Optional["SignCookiesSignCookies"] = Field(alias="signCookies")


class SignCookiesSignCookies(BaseModel):
    signed_cookies: Optional[str] = Field(alias="signedCookies")


SignCookies.model_rebuild()
